package io.renren.modules.app.dao;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import com.baomidou.mybatisplus.mapper.BaseMapper;

import io.renren.modules.app.entity.HPzEntity2;
import io.renren.modules.app.entity.MxzEntity;
import io.renren.modules.app.entity.RjzEntity;

/**
 * 日记账
 *
 * @author lj
 * @email 3499722281@qq.com
 * @date 2019-05-09 09:49:15
 */
@Mapper
public interface MxzDao extends BaseMapper<MxzEntity> {
	// 明细账查询
	List<MxzEntity> mxzSelect_1(MxzEntity mxzEntity);

	// 明细账查询
	List<MxzEntity> mxzSelect_2(MxzEntity mxzEntity);

	// 查询凭证记录
	List<HPzEntity2> select_pz(HPzEntity2 hPzEntity2);

	// 查询kmmc
	String select_kmmc(@Param("ztbm") String ztbm, @Param("kmdm") String kmdm, @Param("len") int len);

	// 返回kmjb
	String select_kmjb(@Param("ztbm") String ztbm);

	String select_kmjb2(@Param("kmjb") String kmjb, @Param("len3") String len3);
}
